@@ -9,16 +9,37 @@ impl Button {
             Button::Void => None,
             Button::LCtrl if hook.flags & 1 != 0 => Some(Button::RCtrl),
             Button::RAlt if hook.flags & 1 != 0 => Some(Button::RAlt),
+            Button::Insert if hook.flags & 1 == 0 => Some(Button::Numpad0),
+            Button::Delete if hook.flags & 1 == 0 => Some(Button::NumpadDot),
+            Button::End if hook.flags & 1 == 0 => Some(Button::Numpad0),
+            Button::DownArrow if hook.flags & 1 == 0 => Some(Button::Numpad2),
+            Button::PageDown if hook.flags & 1 == 0 => Some(Button::Numpad3),
+            Button::LeftArrow if hook.flags & 1 == 0 => Some(Button::Numpad4),
+            Button::RightArrow if hook.flags & 1 == 0 => Some(Button::Numpad6),
+            Button::Home if hook.flags & 1 == 0 => Some(Button::Numpad7),
+            Button::UpArrow if hook.flags & 1 == 0 => Some(Button::Numpad8),
+            Button::PageUp if hook.flags & 1 == 0 => Some(Button::Numpad9),
+            Button::RMeta if hook.flags & 1 == 0 => None,
+
             _ => Some(button),
         }
     }
 
     pub(super) fn to_scancode_and_flag(self) -> Option<(u32, u32)> {
-        const CTRL_KEY_SCANCODE: u32 = 0x1D;
-        const ALT_KEY_SCANCODE: u32 = 0x38;
         match self {
-            Button::RCtrl => Some((CTRL_KEY_SCANCODE, 0x1)),
-            Button::RAlt => Some((ALT_KEY_SCANCODE, 0x1)),
+            Button::RCtrl => Some((*BUTTON_TO_CODE.get(Button::LCtrl as usize)?, 0x1)),
+            Button::RAlt => Some((*BUTTON_TO_CODE.get(Button::LAlt as usize)?, 0x1)),
+            Button::End => Some((*BUTTON_TO_CODE.get(Button::End as usize)?, 0x1)),
+            Button::DownArrow => Some((*BUTTON_TO_CODE.get(Button::DownArrow as usize)?, 0x1)),
+            Button::PageDown => Some((*BUTTON_TO_CODE.get(Button::PageDown as usize)?, 0x1)),
+            Button::LeftArrow => Some((*BUTTON_TO_CODE.get(Button::LeftArrow as usize)?, 0x1)),
+            Button::RightArrow => Some((*BUTTON_TO_CODE.get(Button::RightArrow as usize)?, 0x1)),
+            Button::Home => Some((*BUTTON_TO_CODE.get(Button::Home as usize)?, 0x1)),
+            Button::UpArrow => Some((*BUTTON_TO_CODE.get(Button::UpArrow as usize)?, 0x1)),
+            Button::PageUp => Some((*BUTTON_TO_CODE.get(Button::PageUp as usize)?, 0x1)),
+            Button::Insert => Some((*BUTTON_TO_CODE.get(Button::Insert as usize)?, 0x1)),
+            Button::Delete => Some((*BUTTON_TO_CODE.get(Button::Delete as usize)?, 0x1)),
+            Button::RMeta => Some((*BUTTON_TO_CODE.get(Button::RMeta as usize)?, 0x1)),
             _ => {
                 let code = BUTTON_TO_CODE
                     .get(self as usize)
@@ -190,6 +211,7 @@ button_code_map! {
 
         // LCtrl and RCtrl have the same scancode.
         // RCtrl =>0x1D,
+
         Insert => 0x52,
         Delete => 0x53,
         LeftArrow => 0x4B,
@@ -200,17 +222,30 @@ button_code_map! {
         PageUp => 0x49,
         PageDown => 0x51,
         RightArrow => 0x4D,
-        Numpad1 => 0x4F,
-        Numpad2 => 0x62,
-        Numpad3 => 0x63,
-        Numpad4 => 0x4B,
-        Numpad5 => 0x65,
-        Numpad6 => 0x66,
-        Numpad7 => 0x47,
-        Numpad8 => 0x48,
-        Numpad9 => 0x49,
-        Numpad0 => 0x52,
-        NumpadDot => 0x53,
+
+        // Numpad1 and End have the same scancode.
+        // Numpad1 => 0x4F,
+        // Numpad2 and DownArrow have the same scancode.
+        // Numpad2 => 0x50,
+        // Numpad3 and PageDown have the same scancode.
+        // Numpad3 => 0x51,
+        // Numpad4 and LeftArrow have the same scancode.
+        // Numpad4 => 0x4B,
+        Numpad5 => 0x4C,
+        // Numpad6 and RightArrow have the same scancode.
+        // Numpad6 => 0x4D,
+        // Numpad7 and Home have the same scancode.
+        // Numpad7 => 0x47,
+        // Numpad8 and UpArrow have the same scancode.
+        // Numpad8 => 0x48,
+        // Numpad9 and PageUp have the same scancode.
+        // Numpad9 => 0x49,
+
+        // Numpad0 and Insert have the same sacncode.
+        // Numpad0 => 0x52,
+
+        // NumpadDot and Delete have the same scancode.
+        // NumpadDot => 0x53,
         NumpadSlash => 0x35,
         NumpadAsterisk => 0x37,
         NumpadMinus => 0x4A,
